%global cmake_build_dir build-cmake
%global app_name DNSCryptClient

Name:          dnscrypt-proxy-gui
Version:       1.11.14
Release:       1%{?dist}
Summary:       GUI wrapper for dnscrypt-proxy
License:       GPLv2+
Source0:       https://github.com/F1ash/%{name}/archive/%{version}.tar.gz
URL:           https://github.com/F1ash/%{name}

Requires:      systemd
Requires:      polkit
Requires:      dnscrypt-proxy
Requires:      hicolor-icon-theme

BuildRequires: gcc-c++
BuildRequires: cmake
BuildRequires: glibc-headers
BuildRequires: desktop-file-utils
BuildRequires: qt5-qtbase-devel
BuildRequires: qt5-qtbase-private-devel
%{?_qt5:Requires: %{_qt5}%{?_isa} = %{_qt5_version}}
BuildRequires: kf5-kauth-devel
BuildRequires: kf5-knotifications-devel
BuildRequires: extra-cmake-modules
%{?systemd_requires}
BuildRequires: systemd

%description
The Qt/KF5 GUI wrapper over dnscrypt-proxy
for encrypting all DNS traffic between the user and DNS resolvers,
preventing any spying, spoofing or man-in-the-middle attacks.

%prep
%setup -q

%build
mkdir %{cmake_build_dir}
pushd %{cmake_build_dir}
      %cmake ..
      %{make_build}
popd

%install
pushd %{cmake_build_dir}
      %{make_install}
popd

%check
desktop-file-validate %{buildroot}/%{_datadir}/applications/%{app_name}.desktop

%post
%systemd_post %{app_name}@.service
%systemd_post %{app_name}_test@.service

%preun
%systemd_preun %{app_name}@.service
%systemd_preun %{app_name}_test@.service

%postun
%systemd_postun %{app_name}@.service
%systemd_postun %{app_name}_test@.service

%files
%license LICENSE
%doc README.md
%{_bindir}/%{app_name}
%{_datadir}/applications/%{app_name}.desktop
%{_libexecdir}/kf5/kauth/dnscrypt_client_helper
%{_datadir}/dbus-1/system-services/pro.russianfedora.dnscryptclient.service
%{_datadir}/polkit-1/actions/pro.russianfedora.dnscryptclient.policy
%{_sysconfdir}/dbus-1/system.d/pro.russianfedora.dnscryptclient.conf
%{_libexecdir}/kf5/kauth/dnscrypt_client_test_helper
%{_datadir}/dbus-1/system-services/pro.russianfedora.dnscryptclienttest.service
%{_datadir}/polkit-1/actions/pro.russianfedora.dnscryptclienttest.policy
%{_sysconfdir}/dbus-1/system.d/pro.russianfedora.dnscryptclienttest.conf
%{_libexecdir}/kf5/kauth/dnscrypt_client_reload_helper
%{_datadir}/dbus-1/system-services/pro.russianfedora.dnscryptclientreload.service
%{_datadir}/polkit-1/actions/pro.russianfedora.dnscryptclientreload.policy
%{_sysconfdir}/dbus-1/system.d/pro.russianfedora.dnscryptclientreload.conf
%{_datadir}/knotifications5/%{app_name}.notifyrc
%{_unitdir}/%{app_name}@.service
%{_unitdir}/%{app_name}_test@.service
%{_datadir}/icons/hicolor/64x64/apps/%{app_name}.png

%changelog
* Wed Feb 21 2018 Fl@sh <kaperang07@gmail.com> - 1.11.14-1
- version updated;

* Wed Feb 14 2018 Jan Grulich <jgrulich@redhat.com> - 1.11.11-4
- rebuild (qt5)

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jan 25 2018 Rex Dieter <rdieter@fedoraproject.org> - 1.11.11-2
- rebuild (qt)

* Mon Jan 15 2018 Fl@sh <kaperang07@gmail.com> - 1.11.11-1
- version updated;

* Thu Jan 11 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.11.10-7
- Remove obsolete scriptlets

* Mon Jan 01 2018 Rex Dieter <rdieter@fedoraproject.org> - 1.11.10-6
- rebuild (qt5)

* Mon Nov 27 2017 Rex Dieter <rdieter@fedoraproject.org> - 1.11.10-5
- rebuild (qt5)

* Wed Oct 11 2017 Rex Dieter <rdieter@fedoraproject.org> - 1.11.10-4
- BR: qt5-qtbase-private-devel
- drop explicit qt5/kf5 deps (rpm handles that automatically)

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Jun 28 2017 Fl@sh <kaperang07@gmail.com> - 1.11.10-1
- version updated;

* Tue Jun 27 2017 Fl@sh <kaperang07@gmail.com> - 1.10.10-1
- version updated;

* Thu Jun 22 2017 Fl@sh <kaperang07@gmail.com> - 1.10.9-1
- version updated;

* Sat Jun  3 2017 Fl@sh <kaperang07@gmail.com> - 1.10.8-1
- changed %%files for reload_helper;
- version updated;

* Mon May 22 2017 Fl@sh <kaperang07@gmail.com> - 1.9.8-1
- changed %%files for test_helper;
- version updated;

* Mon Mar 27 2017 Fl@sh <kaperang07@gmail.com> - 1.6.8-2
- release updated;

* Mon Mar 27 2017 Fl@sh <kaperang07@gmail.com> - 1.6.8-1
- version updated;
- changed %%post, %%preun, %%postun, %%files for new systemd unit;

* Sun Jan 29 2017 Fl@sh <kaperang07@gmail.com> - 1.5.7-1
- version updated;

* Tue Jan 10 2017 Fl@sh <kaperang07@gmail.com> - 1.3.7-1
- version updated;

* Fri Dec 16 2016 Fl@sh <kaperang07@gmail.com> - 1.2.3-4
- removed dbus-1 R;
- release updated;

* Wed Dec  7 2016 Fl@sh <kaperang07@gmail.com> - 1.2.3-3
- returned gcc-c++ BR;
- release updated;

* Wed Dec  7 2016 Fl@sh <kaperang07@gmail.com> - 1.2.3-2
- removed gcc-c++ BR, fixed dbus-1 R;
- added scriptlets for update Icon_Cache;
- added %%license in %%files;
- release updated;

* Wed Dec  7 2016 Fl@sh <kaperang07@gmail.com> - 1.2.3-1
- enhanced Summary and %%description;
- removed useless socket unit from scriplets and %%files;
- version updated;

* Mon Nov 28 2016 Fl@sh <kaperang07@gmail.com> - 1.2.2-4
- added cmake, gcc-c++ BR;
- added systemd scriptlets;
- release updated;

* Sun Nov 27 2016 Fl@sh <kaperang07@gmail.com> - 1.2.2-3
- changed package name to comply with the NamingGuidelines;
- release updated;

* Fri Nov 25 2016 Fl@sh <kaperang07@gmail.com> - 1.2.2-2
- changed package name to comply with the NamingGuidelines;
- release updated;

* Fri Nov 25 2016 Fl@sh <kaperang07@gmail.com> - 1.2.2-1
- version updated;

* Tue Nov 22 2016 Fl@sh <kaperang07@gmail.com> - 1.0.0-2
- enhanced Summary and %%description;
- release updated;

* Mon Nov 21 2016 Fl@sh <kaperang07@gmail.com> - 1.0.0-1
- Initial build
